@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2016-09-27'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2016-10-28'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 use strict;
@@ -334,7 +334,7 @@ sub complete_cli_arg {
     while (1) {
         last WORD if ++$i >= @words;
         my $word = $words[$i];
-        #say "D:i=$i, word=$word, ~~@words=",~~@words;
+        #say "D:i=$i, word=$word, ~~\@words=",~~@words;
 
         if ($word eq '--' && $i != $cword) {
             $expects[$i] = {separator=>1};
@@ -424,18 +424,19 @@ sub complete_cli_arg {
                     if (!$max_vals) { $min_vals = $max_vals = 1 }
                 }
 
-                push @{ $parsed_opts{$opt} }, $words[$i+1];
                 for (1 .. $min_vals) {
                     $i++;
                     last WORD if $i >= @words;
                     $expects[$i]{optval} = $opt;
                     $expects[$i]{nth} = $nth;
+                    push @{ $parsed_opts{$opt} }, $words[$i];
                 }
                 for (1 .. $max_vals-$min_vals) {
                     last if $i+$_ >= @words;
                     last if $words[$i+$_] =~ /\A-/; # a new option
                     $expects[$i+$_]{optval} = $opt; # but can also be optname
                     $expects[$i]{nth} = $nth;
+                    push @{ $parsed_opts{$opt} }, $words[$i+$_];
                 }
             } else {
                 # an unknown option, assume it doesn't require argument, unless
@@ -590,7 +591,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.42 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-09-27.
+This document describes version 0.43 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-10-28.
 
 =head1 SYNOPSIS
 
@@ -598,9 +599,6 @@ See L<Getopt::Long::Complete> for an easy way to use this module.
 
 =head1 DESCRIPTION
 
-Note that I deliberately do not support C<ci> (case-insensitive) option here.
-Options that differ only in case often are often and they mean different things.
-
 =head1 FUNCTIONS
 
 
